<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'imscp', language 'id', version '5.0'.
 *
 * @package     imscp
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['areabackup'] = 'Paket arsip';
$string['areacontent'] = 'Konten';
$string['contentheader'] = 'Konten';
$string['deploymenterror'] = 'Galat paket konten!';
$string['imscp:addinstance'] = 'Tambahkan paket konten IMS baru';
$string['imscp:view'] = 'Lihat konten IMS';
$string['indicator:cognitivedepth'] = 'IMS pkg kognitif';
$string['indicator:cognitivedepth_help'] = 'Indikator ini didasarkan pada kedalaman kognitif yang dicapai siswa dalam sumber paket konten IMS.';
$string['indicator:cognitivedepthdef'] = 'IMS pkg kognitif';
$string['indicator:cognitivedepthdef_help'] = 'Peserta telah mencapai persentase keterlibatan kognitif yang ditawarkan oleh sumber daya Paket IMS selama interval analisis ini (Tingkat = Tanpa tampilan, Tampilan)';
$string['indicator:cognitivedepthdef_link'] = 'Learning_analytics_indicators#Cognitive_depth';
$string['indicator:socialbreadth'] = 'IMS pkg sosial';
$string['indicator:socialbreadth_help'] = 'Indikator ini didasarkan pada keluasan sosial yang dicapai siswa dalam sumber paket konten IMS.';
$string['indicator:socialbreadthdef'] = 'IMS pkg sosial';
$string['indicator:socialbreadthdef_help'] = 'Peserta telah mencapai persentase keterlibatan sosial yang ditawarkan oleh sumber daya Paket IMS selama interval analisis ini (Tingkat = Tidak ada partisipasi, Peserta saja)';
$string['indicator:socialbreadthdef_link'] = 'Learning_analytics_indicators#Social_breadth';
$string['keepold'] = 'Arsip paket';
$string['keepoldexplain'] = 'Berapa banyak paket yang harus diarsipkan?';
$string['modulename'] = 'Paket konten IMS';
$string['modulename_help'] = 'Paket konten IMS adalah kumpulan berkas yang dikemas sesuai dengan standar yang disepakati sehingga dapat digunakan kembali dalam sistem yang berbeda. Modul Paket Konten IMS memungkinkan paket konten tersebut untuk diunggah sebagai berkas ZIP dan ditambahkan ke kursus sebagai sumber daya. Konten biasanya ditampilkan melalui beberapa halaman, dengan navigasi antara halaman. Ada berbagai opsi untuk menampilkan konten di jendela sembulan, dengan menu navigasi atau tombol, dll. Paket konten IMS dapat digunakan untuk menyajikan konten dan animasi multimedia.';
$string['modulename_link'] = 'mod/imscp/view';
$string['modulenameplural'] = 'Paket konten IMS';
$string['navigation'] = 'Navigasi';
$string['packagefile'] = 'Paket berkas';
$string['page-mod-imscp-x'] = 'Setiap halaman modul paket konten IMS';
$string['pluginadministration'] = 'Administrasi IMSCP';
$string['pluginname'] = 'Paket konten IMS';
$string['privacy:metadata'] = 'Pengaya paket konten IMS tidak menyimpan data pribadi apa pun.';
$string['search:activity'] = 'Paket konten IMS - informasi sumber';
$string['toc'] = 'TOC';
